@@ -2,7 +2,7 @@
    miscutil.cpp : This file is part of pstoedit
    misc utility functions
 
-   Copyright (C) 1998 - 2019  Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1998 - 2020  Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 
 */
 #include "miscutil.h"
+#include <memory>
 
 #ifdef OS_WIN32_WCE
 #include "WinCEAdapter.h"
@@ -82,7 +83,7 @@ void convertBackSlashes(char *) { }
 void convertBackSlashes(char *fileName)
 {
  	char *c ;
-	while ((c = strchr(fileName, '\\')) != NIL)
+	while ((c = strchr(fileName, '\\')) != nullptr)
 		*c = '/';
 }
 #endif
@@ -201,9 +202,9 @@ RSString full_qualified_tempnam(const char *pref)
 #else 
 #if defined (__BCPLUSPLUS__) || defined (__TCPLUSPLUS__)
 /* borland has a prototype that expects a char * as second arg */
-	char *filename = TEMPNAM(0, (char *) pref);
+	char *filename = TEMPNAM(nullptr, (char *) pref);
 #else
-	char *filename = TEMPNAM(0, pref);
+	char *filename = TEMPNAM(nullptr, pref);
 #endif
 	// W95: Fkt. tempnam() erzeugt Filename+Pfad
 	// W3.1: es wird nur der Name zurueckgegeben
@@ -217,10 +218,12 @@ RSString full_qualified_tempnam(const char *pref)
 #else
 	convertBackSlashes(filename);
 	if ((strchr(filename, '\\') == nullptr) && (strchr(filename, '/') == nullptr)) {	// keine Pfadangaben..
+		RSString result("");
 		char cwd[400];
-		(void) GETCWD(cwd, 400);
-		RSString result = cwd;
-		result += "/";
+		if (GETCWD(cwd, 400)) {
+		    result += cwd;
+			result += "/";
+		}
 		result += filename;
 		free(filename);
 		return result;
@@ -232,11 +235,11 @@ RSString full_qualified_tempnam(const char *pref)
 #endif
 }
 
-unsigned short hextoint(const char hexchar) 
+unsigned short hextoint(const char hexchar)
 {
 	char h = hexchar;
 	if (h >= 'a' && h <='f') h += 'A' - 'a'; // normalize lowercase to uppercase
-	unsigned short r = ( h <= '9' ) ? (h - '0') : (h + 10 - 'A' ) ; //lint !e732
+	const unsigned short r = ( h <= '9' ) ? (h - '0') : (h + 10 - 'A' ) ; //lint !e732
 	return r;
 }
 #if defined(_WIN32)
@@ -274,7 +277,7 @@ RSString tryregistry(HKEY hKey, LPCSTR subkeyn, LPCSTR key)
 #else
 										  key,	// "SOFTWARE\\wglunz\\pstoedit\\plugindir", //LPCSTR lpValueName,
 #endif
-										  NIL,	// LPDWORD lpReserved,
+										  nullptr,	// LPDWORD lpReserved,
 										  &valuetype,	// LPDWORD lpType,
 										  value,	// LPBYTE lpData,
 										  &bufsize	// LPDWORD lpcbData
@@ -329,7 +332,7 @@ RSString getRegistryValue(ostream & errstream, const char *typekey, const char *
 
 	getini(0, errstream, pszFileName, inifilename, (int) sizeof(pszFileName));
 	hini = PrfOpenProfile(hab, pszFileName);
-	rc = PrfQueryProfileString(hini, typekey, key, NIL, (PVOID) buffer, (LONG) sizeof(buffer));
+	rc = PrfQueryProfileString(hini, typekey, key, nullptr, (PVOID) buffer, (LONG) sizeof(buffer));
 	PrfCloseProfile(hini);
 	WinTerminate(hab);
 
@@ -600,7 +603,7 @@ unsigned long P_GetPathToMyself(const char *name, char *returnbuffer, unsigned l
 void errorMessage(const char *errortext)
 {
 #if 0 // defined(_WIN32)
-	MessageBox(NIL, errortext, "pstoedit", MB_OK | MB_ICONEXCLAMATION | MB_TASKMODAL);
+	MessageBox(nullptr, errortext, "pstoedit", MB_OK | MB_ICONEXCLAMATION | MB_TASKMODAL);
 #else
 	cerr << errortext << endl;
 #endif
@@ -612,11 +615,11 @@ DLLEXPORT RSString getOutputFileNameFromPageNumber(const char * const outputFile
 	const char PAGENUMBER_String[] = "%PAGENUMBER%";
 	const char * pagestringptr_1 = strstr(outputFileTemplate,PAGENUMBER_String);
 	const char * pagestringptr_2 = strstr(outputFileTemplate,"%d");
-	if ((pagestringptr_1 == NIL) && (pagestringptr_2 == NIL)) {
+	if ((pagestringptr_1 == nullptr) && (pagestringptr_2 == nullptr)) {
 		return RSString(outputFileTemplate);
 	} else  {
 		const size_t size = strlen(outputFileTemplate) + 30;
-		auto newname = new char[ size ];
+		std::unique_ptr<char[]> newname ( new char[ size ]);
 
 		RSString formatting("%");
 		formatting += pagenumberformatOption;
@@ -633,22 +636,21 @@ DLLEXPORT RSString getOutputFileNameFromPageNumber(const char * const outputFile
 
 		if (pagestringptr_1) // preference to %PAGENUMBER%
 		{
-			strncpy_s(newname,size,outputFileTemplate,pagestringptr_1-outputFileTemplate); // copy up to %PAGENUMBER%
+			strncpy_s(newname.get(),size,outputFileTemplate,pagestringptr_1-outputFileTemplate); // copy up to %PAGENUMBER%
 			// now copy page number
-			strcat_s(newname,size,pagenumberstring);
+			strcat_s(newname.get(),size,pagenumberstring);
 			// now copy trailer
-			strcat_s(newname,size,pagestringptr_1+strlen(PAGENUMBER_String));
+			strcat_s(newname.get(),size,pagestringptr_1+strlen(PAGENUMBER_String));
 
 		} else {
-			strncpy_s(newname,size,outputFileTemplate,pagestringptr_2-outputFileTemplate); // copy up to %PAGENUMBER%
+			strncpy_s(newname.get(),size,outputFileTemplate,pagestringptr_2-outputFileTemplate); // copy up to %PAGENUMBER%
 			// now copy page number
-			strcat_s(newname,size,pagenumberstring);
+			strcat_s(newname.get(),size,pagenumberstring);
 			// now copy trailer
-			strcat_s(newname,size,pagestringptr_2+strlen("%d"));		
+			strcat_s(newname.get(),size,pagestringptr_2+strlen("%d"));
 		}
 		//cout << "newname " << newname << endl;
-		const RSString result (newname);
-		delete [] newname;
+		const RSString result (newname.get());
 		return result;
 	}
 }
@@ -861,9 +863,9 @@ void FontMapper::readMappingTable(ostream & errstream, const char *filename)
 		//	errstream << "empty line in fontmap - ignored " << endl;
 			continue;
 		}
-		char *original = readword(lineptr);
+		const char * const original = readword(lineptr);
 		skipws(lineptr);
-		char *replacement = readword(lineptr);
+		const char * const replacement = readword(lineptr);
 		if (original && replacement) {
 			// errstream << "\"" << original << "\" \"" << replacement <<"\""<< endl;
 		        if (replacement[0] == '/') {
